# Write a script to generate this file, along the lines of
# `grep -r -i "TODO" . >> TODO.md` but something to eliminate duplicates.

./redi.py:	# TODO: add `a` switch to redi to tell it to keep all data points from the input file.
./batch.py:        # TODO: refactor code to use ConfigParser.RawConfigParser in order to
./redi.py:    # TODO: UPDATE COMMENT HERE
./redi.py:        # TODO better description of commandline argument handling
./redi.py:    #TODO: make parameters configurable
./redi.py:    # TODO: post processing will go here
./redi.py:    # TODO: make this able to run against a local file if desired
./redi.py:        # TODO: Add preproc errors to report
./redi.py:# TODO: look at adding a switch to RED-I, that will need to be caught here, that
./redi.py:# @TODO: remove settings from signature
./redi.py:    TODO: fix load_rules and load_prerules for better parallelism
./redi.py:    # TODO figure out if this creates a sub process or not
./redi.py:    # TODO need to check for program exe3cution otherwise give error
./report.py:        # TODO: Replace this with a "backup_courier" constructor injection
./report.py:        # TODO: remove dependency on the order of the xml elements in the report
./upload.py:    @TODO: evaluate performance
./utils/GetEmrData.py:    # TODO: Replace csv2xml.py entirely?
./utils/SimpleConfigParser.py:# TODO:
./utils/throttle.py:        # @TODO: investigate why the deque is not
# TODO: make tests: requirement -- msg= mock requires setuptools>=17.1. Aborting installation
TODO: make tests requirement- msg=sudo easy_install sftpserver
TODO: make all settings files pythonic aka config.yml .. etc using YAML standard
TODO: take NOT_DONE examples for values without units data points out of vagrant/redi_out_reference.csv for hcv examples
# TODO: -K 'keep all results' fail if in the settings.ini doesn't have Y-M-D H:M:S



# TODO: Modify dates on ConMeds forms to validate for H:M:S.
=======

** TODO: To be able to make pull request for keep-all switch . Write unit test(s) for all the functions touched by the keep-all commandline switch.
** TODO: TO be able to make a pull request for keep-all switch. Write end-to-end tests to take in fake conmeds data, call the sithc, pass in the file, use redcap     api to query out the data and compare to input csv. Use N Rejack scripts to create test data.
** TODO: change install redcap setting to enable table based authentication.    
** TODO: find out why sometimes redcap can't talk to mysql. restart mysql fixes. may need to add this to the bootstrap to restart apache and mysql right at the end.

